#!/usr/bin/env python
#
# This file is part of Jungle Math
# Author(s): Victoria Valdez and Zoe Galbraith, Girlstart
# Copyright 2008
#
# Source code is derived from Girlstart's Project IT Girl Game Templates:
# http://itgirl.dreamhosters.com/itgirlgames/, http://www.girlstart.org/itgirl
# See the credits file for image sources.
#
# Jungle Math is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Jungle Math is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Jungle Math.  If not, see <http://www.gnu.org/licenses/>.

import pygame, ActivityBase
from helpers import *

class Activity1(ActivityBase.ActivityBase):
	def __init__(self,topleft,background_image,main_image_file,completed_image_file):
		ActivityBase.ActivityBase.__init__(self,topleft,background_image,main_image_file,completed_image_file)

	def askQuestion(self, questionText, answer1, answer1rect, answer2, answer2rect, answer3, answer3rect, correctAnswerrect):
		# questionText is the string of the question
		# answer1, answer2 and answer3 are the possible answers for the user to choose
		# answer1rect, answer2rect and answer3rect are the Rects that describe where the images for
		# the answers need to be drawn.
		# correctAnswer is the correct answer
		
		# Set up the font for our question.  Redraw the background first to clear the screen
		self.screen.blit(self.background, (0, 0))
		font = pygame.font.Font(None, 30)
		text = font.render(questionText, 1, (255, 255, 255))
		textrect = text.get_rect()
		textrect.centerx, textrect.centery = self.area.centerx,75
		self.screen.blit(text, textrect)
		
		# Draw our answers to the screen
		self.screen.blit(answer1, answer1rect)
		self.screen.blit(answer2, answer2rect)
		self.screen.blit(answer3, answer3rect)
		
		pygame.display.flip()
		
		# Now let's loop waiting for the user's answer
		answered = False
		while not answered:
			for event in pygame.event.get():
				if event.type == pygame.QUIT:
					sys.exit()
				elif event.type == pygame.MOUSEBUTTONDOWN:
						if answer1rect.collidepoint(event.pos):
							# If we're here, then the user has clicked on one of the answers.
							answered = True
							if answer1rect == correctAnswerrect:
								# User answered correctly, let them know
								correct = True
							else:
								correct = False
						elif answer2rect.collidepoint(event.pos):
							answered = True
							if answer2rect == correctAnswerrect:
								correct = True
							else:
								correct = False
						elif answer3rect.collidepoint(event.pos):
							answered = True
							if answer3rect == correctAnswerrect:
								correct = True
							else:
								correct = False

		# The user has answered.  Display the results of their answer.  Remember, we need to redraw the background
		# in order to get rid of the previous stuff drawn to the screen.
		if correct:
			windowsize = windowwidth, windowheight = 750, 500
			screen = pygame.display.set_mode(windowsize)
			area = screen.get_rect()
			background,background_rect = load_image("newgiraffe transition screen.png")
			self.screen.blit(background,background_rect)

		else:
			fontlose = pygame.font.Font(None, 50)
			text = fontlose.render("Sorry, try again :( Click anywhere to continue", 100, (250,250,250))
			self.screen.blit(self.background, (0, 0))
			textrect = text.get_rect()
			textrect.centerx, textrect.centery = self.area.centerx,75
			self.screen.blit(text, textrect)
		
		pygame.display.flip()
		
		# Now, wait for the user to click a key to continue:
		answered = False
		while not answered:
			for event in pygame.event.get():
				if event.type == pygame.QUIT:
					sys.exit()
				elif event.type == pygame.MOUSEBUTTONDOWN:
					answered = True				
		
		return correct
	
	def play(self):
		print "in play"
		self.image = self.completed_image
		self.completed_image_rect.topleft = self.rect.topleft
		self.rect = self.completed_image_rect

				# Load all of our images for our question:
		answer1, answer1rect = load_image("answerswrong1.png")
		answer2, answer2rect = load_image("answercorrect1.png")
		answer3, answer3rect = load_image("answerwrong1.png")
		answer1rect.center = 100,400
		answer2rect.center = 300,400
		answer3rect.center = 500,400

		while not self.activity_completed:
			for event in pygame.event.get():
				if event.type == pygame.QUIT:
					sys.exit()
			# Ask our question until they get it right
			if self.askQuestion("What does 156 + 34 equal?", answer1, answer1rect, answer2, answer2rect, answer3, answer3rect, answer2rect):
				self.activity_completed = True

		self.image = self.completed_image
		self.completed_image_rect.topleft = self.rect.topleft
		self.rect = self.completed_image_rect

class Activity2(ActivityBase.ActivityBase):
	def __init__(self,topleft,background_image,main_image_file,completed_image_file):
		ActivityBase.ActivityBase.__init__(self,topleft,background_image,main_image_file,completed_image_file)

	def askQuestion(self, questionText, answer1, answer1rect, answer2, answer2rect, answer3, answer3rect, correctAnswerrect):
		# questionText is the string of the question
		# answer1, answer2 and answer3 are the possible answers for the user to choose
		# answer1rect, answer2rect and answer3rect are the Rects that describe where the images for
		# the answers need to be drawn.
		# correctAnswer is the correct answer
		
		# Set up the font for our question.  Redraw the background first to clear the screen
		self.screen.blit(self.background, (0, 0))
		font = pygame.font.Font(None, 30)
		text = font.render(questionText, 1, (255, 255, 255))
		textrect = text.get_rect()
		textrect.centerx, textrect.centery = self.area.centerx,75
		self.screen.blit(text, textrect)
		
		# Draw our answers to the screen
		self.screen.blit(answer1, answer1rect)
		self.screen.blit(answer2, answer2rect)
		self.screen.blit(answer3, answer3rect)
		
		pygame.display.flip()
		
		# Now let's loop waiting for the user's answer
		answered = False
		while not answered:
			for event in pygame.event.get():
				if event.type == pygame.QUIT:
					sys.exit()
				elif event.type == pygame.MOUSEBUTTONDOWN:
						if answer1rect.collidepoint(event.pos):
							# If we're here, then the user has clicked on one of the answers.
							answered = True
							if answer1rect == correctAnswerrect:
								# User answered correctly, let them know
								correct = True
							else:
								correct = False
						elif answer2rect.collidepoint(event.pos):
							answered = True
							if answer2rect == correctAnswerrect:
								correct = True
							else:
								correct = False
						elif answer3rect.collidepoint(event.pos):
							answered = True
							if answer3rect == correctAnswerrect:
								correct = True
							else:
								correct = False

		# The user has answered.  Display the results of their answer.  Remember, we need to redraw the background
		# in order to get rid of the previous stuff drawn to the screen.
		if correct:
			windowsize = windowwidth, windowheight = 750, 500
			screen = pygame.display.set_mode(windowsize)
			area = screen.get_rect()
			background,background_rect = load_image("snakeytransitionpage.png")
			self.screen.blit(background,background_rect)
			pygame.display.flip()
			
		else:
			fontlose = pygame.font.Font(None, 50)
			text = fontlose.render("Sorry, try again :( Click anywhere to continue", 100, (250,250,250))
			self.screen.blit(self.background, (0, 0))
			textrect = text.get_rect()
			textrect.centerx, textrect.centery = self.area.centerx,75
			self.screen.blit(text, textrect)
		
		pygame.display.flip()
		
		# Now, wait for the user to click a key to continue:
		answered = False
		while not answered:
			for event in pygame.event.get():
				if event.type == pygame.QUIT:
					sys.exit()
				elif event.type == pygame.MOUSEBUTTONDOWN:
					answered = True				
		
		return correct
	
	def play(self):
		print "in play"
		self.image = self.completed_image
		self.completed_image_rect.topleft = self.rect.topleft
		self.rect = self.completed_image_rect

				# Load all of our images for our question:
		answer1, answer1rect = load_image("correct2.png")
		answer2, answer2rect = load_image("wrong22.png")
		answer3, answer3rect = load_image("wrong2.png")
		answer1rect.center = 100,400
		answer2rect.center = 300,400
		answer3rect.center = 500,400

		while not self.activity_completed:
			for event in pygame.event.get():
				if event.type == pygame.QUIT:
					sys.exit()
			# Ask our question until they get it right
			if self.askQuestion("What does 215-55 equal?", answer1, answer1rect, answer2, answer2rect, answer3, answer3rect, answer1rect):
				self.activity_completed = True

		self.image = self.completed_image
		self.completed_image_rect.topleft = self.rect.topleft
		self.rect = self.completed_image_rect

class Activity3(ActivityBase.ActivityBase):
	def __init__(self,topleft,background_image,main_image_file,completed_image_file):
		ActivityBase.ActivityBase.__init__(self,topleft,background_image,main_image_file,completed_image_file)

	def askQuestion(self, questionText, answer1, answer1rect, answer2, answer2rect, answer3, answer3rect, correctAnswerrect):
		# questionText is the string of the question
		# answer1, answer2 and answer3 are the possible answers for the user to choose
		# answer1rect, answer2rect and answer3rect are the Rects that describe where the images for
		# the answers need to be drawn.
		# correctAnswer is the correct answer
		
		# Set up the font for our question.  Redraw the background first to clear the screen
		self.screen.blit(self.background, (0, 0))
		font = pygame.font.Font(None, 30)
		text = font.render(questionText, 1, (255, 255, 255))
		textrect = text.get_rect()
		textrect.centerx, textrect.centery = self.area.centerx,75
		self.screen.blit(text, textrect)
		
		# Draw our answers to the screen
		self.screen.blit(answer1, answer1rect)
		self.screen.blit(answer2, answer2rect)
		self.screen.blit(answer3, answer3rect)
		
		pygame.display.flip()
		
		# Now let's loop waiting for the user's answer
		answered = False
		while not answered:
			for event in pygame.event.get():
				if event.type == pygame.QUIT:
					sys.exit()
				elif event.type == pygame.MOUSEBUTTONDOWN:
						if answer1rect.collidepoint(event.pos):
							# If we're here, then the user has clicked on one of the answers.
							answered = True
							if answer1rect == correctAnswerrect:
								# User answered correctly, let them know
								correct = True
							else:
								correct = False
						elif answer2rect.collidepoint(event.pos):
							answered = True
							if answer2rect == correctAnswerrect:
								correct = True
							else:
								correct = False
						elif answer3rect.collidepoint(event.pos):
							answered = True
							if answer3rect == correctAnswerrect:
								correct = True
							else:
								correct = False

		# The user has answered.  Display the results of their answer.  Remember, we need to redraw the background
		# in order to get rid of the previous stuff drawn to the screen.
		if correct:
			windowsize = windowwidth, windowheight = 750, 500
			screen = pygame.display.set_mode(windowsize)
			area = screen.get_rect()
			background,background_rect = load_image("snake background copy.png")
			self.screen.blit(background,background_rect)
		else:
			fontlose = pygame.font.Font(None, 50)
			text = fontlose.render("Sorry, try again :( Click anywhere to continue", 100, (250,250,250))
			self.screen.blit(self.background, (0, 0))
			textrect = text.get_rect()
			textrect.centerx, textrect.centery = self.area.centerx,75
			self.screen.blit(text, textrect)
		
		pygame.display.flip()
		
		# Now, wait for the user to click a key to continue:
		answered = False
		while not answered:
			for event in pygame.event.get():
				if event.type == pygame.QUIT:
					sys.exit()
				elif event.type == pygame.MOUSEBUTTONDOWN:
					answered = True				
		
		return correct
	
	def play(self):
		print "in play"
		self.image = self.completed_image
		self.completed_image_rect.topleft = self.rect.topleft
		self.rect = self.completed_image_rect

				# Load all of our images for our question:
		answer1, answer1rect = load_image("wrong33.png")
		answer2, answer2rect = load_image("wrong3.png")
		answer3, answer3rect = load_image("correct3.png")
		answer1rect.center = 100,400
		answer2rect.center = 300,400
		answer3rect.center = 500,400

		while not self.activity_completed:
			for event in pygame.event.get():
				if event.type == pygame.QUIT:
					sys.exit()
			# Ask our question until they get it right
			if self.askQuestion("What does 12*3 equal?", answer1, answer1rect, answer2, answer2rect, answer3, answer3rect, answer3rect):
				self.activity_completed = True

		self.image = self.completed_image
		self.completed_image_rect.topleft = self.rect.topleft
		self.rect = self.completed_image_rect

class Activity4(ActivityBase.ActivityBase):
	def __init__(self,topleft,background_image,main_image_file,completed_image_file):
		ActivityBase.ActivityBase.__init__(self,topleft,background_image,main_image_file,completed_image_file)

	def askQuestion(self, questionText, answer1, answer1rect, answer2, answer2rect, answer3, answer3rect, correctAnswerrect):
		# questionText is the string of the question
		# answer1, answer2 and answer3 are the possible answers for the user to choose
		# answer1rect, answer2rect and answer3rect are the Rects that describe where the images for
		# the answers need to be drawn.
		# correctAnswer is the correct answer
		
		# Set up the font for our question.  Redraw the background first to clear the screen
		self.screen.blit(self.background, (0, 0))
		font = pygame.font.Font(None, 30)
		text = font.render(questionText, 1, (255, 255, 255))
		textrect = text.get_rect()
		textrect.centerx, textrect.centery = self.area.centerx,75
		self.screen.blit(text, textrect)
		
		# Draw our answers to the screen
		self.screen.blit(answer1, answer1rect)
		self.screen.blit(answer2, answer2rect)
		self.screen.blit(answer3, answer3rect)
		
		pygame.display.flip()
		
		# Now let's loop waiting for the user's answer
		answered = False
		while not answered:
			for event in pygame.event.get():
				if event.type == pygame.QUIT:
					sys.exit()
				elif event.type == pygame.MOUSEBUTTONDOWN:
						if answer1rect.collidepoint(event.pos):
							# If we're here, then the user has clicked on one of the answers.
							answered = True
							if answer1rect == correctAnswerrect:
								# User answered correctly, let them know
								correct = True
							else:
								correct = False
						elif answer2rect.collidepoint(event.pos):
							answered = True
							if answer2rect == correctAnswerrect:
								correct = True
							else:
								correct = False
						elif answer3rect.collidepoint(event.pos):
							answered = True
							if answer3rect == correctAnswerrect:
								correct = True
							else:
								correct = False

		# The user has answered.  Display the results of their answer.  Remember, we need to redraw the background
		# in order to get rid of the previous stuff drawn to the screen.
		if correct:
			windowsize = windowwidth, windowheight = 750, 500
			screen = pygame.display.set_mode(windowsize)
			area = screen.get_rect()
			background,background_rect = load_image("hello copy.png")
			self.screen.blit(background,background_rect)
		else:
			fontlose = pygame.font.Font(None, 50)
			text = fontlose.render("Sorry, try again :( Click anywhere to continue", 100, (250,250,250))
			self.screen.blit(self.background, (0, 0))
			textrect = text.get_rect()
			textrect.centerx, textrect.centery = self.area.centerx,75
			self.screen.blit(text, textrect)
		
		pygame.display.flip()
		
		# Now, wait for the user to click a key to continue:
		answered = False
		while not answered:
			for event in pygame.event.get():
				if event.type == pygame.QUIT:
					sys.exit()
				elif event.type == pygame.MOUSEBUTTONDOWN:
					answered = True				
		
		return correct
	
	def play(self):
		print "in play"
		self.image = self.completed_image
		self.completed_image_rect.topleft = self.rect.topleft
		self.rect = self.completed_image_rect

				# Load all of our images for our question:
		answer1, answer1rect = load_image("wrong4.png")
		answer2, answer2rect = load_image("correct4.png")
		answer3, answer3rect = load_image("wrong44.png")
		answer1rect.center = 100,400
		answer2rect.center = 300,400
		answer3rect.center = 500,400

		while not self.activity_completed:
			for event in pygame.event.get():
				if event.type == pygame.QUIT:
					sys.exit()
			# Ask our question until they get it right
			if self.askQuestion("What does 28/7 equal?", answer1, answer1rect, answer2, answer2rect, answer3, answer3rect, answer2rect):
				self.activity_completed = True

		self.image = self.completed_image
		self.completed_image_rect.topleft = self.rect.topleft
		self.rect = self.completed_image_rect
